package org.hibernate.cache;

/**
 * Defines the contract for a cache region which will specifically be used to
 * store entity data.
 *
 * @author Steve Ebersole
 */
public interface EntityRegion extends AccessProtectableRegion {

	/**
	 * Iitialize the entity data region by letting it know some information 
	 * regarding the type of data that will be stored there.
	 *
	 * @param source Metadata about the type of data this region will be
	 * storing.
	 */
	public void intialize(OptimisticCacheSource source);

	/**
	 * Get an item from the cache; however, unlike {@link #get} here the item
	 * will be retrieved within any transactional semantics of the underlying
	 * region (i.e. {@link #get} explicitly disassociates from any ongoing
	 * transaction semantics).
	 *
	 * @param key The key of the item to be retrieved.
	 * @return the cached object or <tt>null</tt>
	 * @throws CacheException Indicates a problem accessing the item.
	 */
	public Object read(Object key) throws CacheException;
	
}
