package org.hibernate.cache;

/**
 * Defines the contract for a cache region which will specifically be used to
 * store query results.
 *
 * @author Steve Ebersole
 */
public interface QueryResultsRegion extends Region {

	/**
	 * Get query results from the underlying cache region.
	 *
	 * @param key The key of the results to be retrieved.
	 * @return the cached object or <tt>null</tt>
	 * @throws CacheException Indicates a problem accessing the region.
	 */
	public Object get(Object key) throws CacheException;

	/**
	 * Write query results into the underlying region.
	 *
	 * @param key The query key
	 * @param value The query results.
	 * @throws CacheException Indicates a problem accessing the region.
	 */
	public void put(Object key, Object value) throws CacheException;

	/**
	 * Used when there is a problem recontructing the query results from the
	 * cached representation.
	 *
	 * @param key The cache key.
	 * @throws CacheException Indicates a problem accessing the region.
	 */
	public void remove(Object key) throws CacheException;
}
